@@ -6,18 +6,18 @@ sub dounfoldtest {
     my $out = shift;
     my $method = shift;
 
-    open IN, "<testin/$in.in" or die "open: $!";
+    open IN, "<test-data/$in.in" or die "open: $!";
     my $instring = join '', <IN>;
     close IN;
     my $lf = Text::LineFold->new(@_);
     my $unfolded = $lf->unfold($instring, $method);
 
     my $outstring = '';
-    if (open OUT, "<testin/$out.out") {
+    if (open OUT, "<test-data/$out.out") {
         $outstring = join '', <OUT>;
         close OUT;
     } else {
-        open XXX, ">testin/$out.xxx";
+        open XXX, ">test-data/$out.xxx";
         print XXX $unfolded;
         close XXX;
     }
@@ -29,7 +29,7 @@ sub do5tests {
     my $in = shift;
     my $out = shift;
 
-    open IN, "<testin/$in.in" or die "open: $!";
+    open IN, "<test-data/$in.in" or die "open: $!";
     my $instring = join '', <IN>;
     close IN;
     my $lf = Text::LineFold->new(@_);
@@ -37,11 +37,11 @@ sub do5tests {
     foreach my $method (qw(PLAIN FIXED FLOWED)) {
 	$folded{$method} = $lf->fold($instring, $method);
 	my $outstring = '';
-	if (open OUT, "<testin/$out.".(lc $method).".out") {
+	if (open OUT, "<test-data/$out.".(lc $method).".out") {
 	    $outstring = join '', <OUT>;
 	    close OUT;
 	} else {
-	    open XXX, ">testin/$out.".(lc $method).".xxx";
+	    open XXX, ">test-data/$out.".(lc $method).".xxx";
 	    print XXX $folded{$method};
 	    close XXX;
 	}
@@ -49,8 +49,12 @@ sub do5tests {
     }
     foreach my $method (qw(FIXED FLOWED)) {
 	my $outstring = $lf->unfold($folded{$method}, $method);
+	if (open IN, "<test-data/$in.norm.in") {
+	    $instring = join '', <IN>;
+	    close IN;
+	}
 	is($outstring, $instring);
-	#XXXopen XXX, ">testin/$out.".(lc $method).".xxx";
+	#XXXopen XXX, ">test-data/$out.".(lc $method).".xxx";
 	#XXXprint XXX $outstring;
 	#XXXclose XXX;
     }
@@ -60,18 +64,18 @@ sub dowraptest {
     my $in = shift;
     my $out = shift;
 
-    open IN, "<testin/$in.in" or die "open: $!";
+    open IN, "<test-data/$in.in" or die "open: $!";
     my $instring = join '', <IN>;
     close IN;
     my $lf = Text::LineFold->new(@_);
     my $folded = $lf->fold("\t", ' ' x 4, $instring);
 
     my $outstring = '';
-    if (open OUT, "<testin/$out.wrap.out") {
+    if (open OUT, "<test-data/$out.wrap.out") {
         $outstring = join '', <OUT>;
         close OUT;
     } else {
-        open XXX, ">testin/$out.wrap.xxx";
+        open XXX, ">test-data/$out.wrap.xxx";
         print XXX $folded;
         close XXX;
     }
